summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/keylistview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui/keylistview.cpp')
-rw-r--r--certmanager/lib/ui/keylistview.cpp132
1 files changed, 66 insertions, 66 deletions
diff --git a/certmanager/lib/ui/keylistview.cpp b/certmanager/lib/ui/keylistview.cpp
index d8afcc596..7519f7e81 100644
--- a/certmanager/lib/ui/keylistview.cpp
+++ b/certmanager/lib/ui/keylistview.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -63,15 +63,15 @@ namespace {
class ItemToolTip : public TQToolTip {
public:
- ItemToolTip( Kleo::KeyListView * parent );
+ ItemToolTip( Kleo::KeyListView * tqparent );
protected:
void maybeTip( const TQPoint & p );
private:
Kleo::KeyListView * mKeyListView;
};
- ItemToolTip::ItemToolTip( Kleo::KeyListView * parent )
- : TQToolTip( parent->viewport() ), mKeyListView( parent ) {}
+ ItemToolTip::ItemToolTip( Kleo::KeyListView * tqparent )
+ : TQToolTip( tqparent->viewport() ), mKeyListView( tqparent ) {}
void ItemToolTip::maybeTip( const TQPoint & p ) {
if ( !mKeyListView )
@@ -117,7 +117,7 @@ struct Kleo::KeyListView::Private {
std::map<TQCString,KeyListViewItem*> itemMap;
};
-// a list of signals where we want to tqreplace TQListViewItem with
+// a list of signals where we want to replace TQListViewItem with
// Kleo:KeyListViewItem:
static const struct {
const char * source;
@@ -135,8 +135,8 @@ static const struct {
static const int numSignalReplacements = sizeof signalReplacements / sizeof *signalReplacements;
-Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const DisplayStrategy * displayStrategy, TQWidget * parent, const char * name, WFlags f )
- : KListView( parent, name ),
+Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const DisplayStrategy * displayStrategy, TQWidget * tqparent, const char * name, WFlags f )
+ : KListView( tqparent, name ),
mColumnStrategy( columnStrategy ),
mDisplayStrategy ( displayStrategy ),
mHierarchical( false )
@@ -173,7 +173,7 @@ Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const Dis
Kleo::KeyListView::~KeyListView() {
d->updateTimer->stop();
- // need to clear here, since in ~TQListView, our children won't have
+ // need to clear here, since in ~TQListView, our tqchildren won't have
// a valid listView() pointing to us anymore, and their dtors try to
// unregister from us.
clear();
@@ -261,7 +261,7 @@ void Kleo::KeyListView::deregisterItem( const KeyListViewItem * item ) {
if ( !item )
return;
std::map<TQCString,KeyListViewItem*>::iterator it
- = d->itemMap.find( item->key().primaryFingerprint() );
+ = d->itemMap.tqfind( item->key().primaryFingerprint() );
if ( it == d->itemMap.end() )
return;
Q_ASSERT( it->second == item );
@@ -276,9 +276,9 @@ void Kleo::KeyListView::doHierarchicalInsert( const GpgME::Key & key ) {
return;
KeyListViewItem * item = 0;
if ( !key.isRoot() )
- if ( KeyListViewItem * parent = itemByFingerprint( key.chainID() ) ) {
- item = new KeyListViewItem( parent, key );
- parent->setOpen( true );
+ if ( KeyListViewItem * tqparent = itemByFingerprint( key.chainID() ) ) {
+ item = new KeyListViewItem( tqparent, key );
+ tqparent->setOpen( true );
}
if ( !item )
item = new KeyListViewItem( this, key ); // top-level (for now)
@@ -293,12 +293,12 @@ void Kleo::KeyListView::gatherScattered() {
item = item->nextSibling();
if ( cur->key().isRoot() )
continue;
- if ( KeyListViewItem * parent = itemByFingerprint( cur->key().chainID() ) ) {
- // found a new parent...
+ if ( KeyListViewItem * tqparent = itemByFingerprint( cur->key().chainID() ) ) {
+ // found a new tqparent...
// ### todo: optimize by suppressing removing/adding the item to the itemMap...
takeItem( cur );
- parent->insertItem( cur );
- parent->setOpen( true );
+ tqparent->insertItem( cur );
+ tqparent->setOpen( true );
}
}
}
@@ -313,8 +313,8 @@ void Kleo::KeyListView::scatterGathered( TQListViewItem * start ) {
assert( cur->childCount() == 0 );
// ### todo: optimize by suppressing removing/adding the item to the itemMap...
- if ( cur->parent() )
- cur->parent()->takeItem( cur );
+ if ( cur->tqparent() )
+ cur->tqparent()->takeItem( cur );
else
takeItem( cur );
insertItem( cur );
@@ -324,7 +324,7 @@ void Kleo::KeyListView::scatterGathered( TQListViewItem * start ) {
Kleo::KeyListViewItem * Kleo::KeyListView::itemByFingerprint( const TQCString & s ) const {
if ( s.isEmpty() )
return 0;
- const std::map<TQCString,KeyListViewItem*>::const_iterator it = d->itemMap.find( s );
+ const std::map<TQCString,KeyListViewItem*>::const_iterator it = d->itemMap.tqfind( s );
if ( it == d->itemMap.end() )
return 0;
return it->second;
@@ -370,39 +370,39 @@ void Kleo::KeyListView::slotEmitContextMenu( KListView*, TQListViewItem * item,
//
//
-Kleo::KeyListViewItem::KeyListViewItem( KeyListView * parent, const GpgME::Key & key )
- : TQListViewItem( parent )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListView * tqparent, const GpgME::Key & key )
+ : TQListViewItem( tqparent )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Key & key )
- : TQListViewItem( parent, after )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Key & key )
+ : TQListViewItem( tqparent, after )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * parent, const GpgME::Key & key )
- : TQListViewItem( parent )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * tqparent, const GpgME::Key & key )
+ : TQListViewItem( tqparent )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Key & key )
- : TQListViewItem( parent, after )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Key & key )
+ : TQListViewItem( tqparent, after )
{
setKey( key );
}
Kleo::KeyListViewItem::~KeyListViewItem() {
- // delete the children first... When children are deleted in the
- // QLVI dtor, they don't have listView() anymore, thus they don't
+ // delete the tqchildren first... When tqchildren are deleted in the
+ // TQLVI dtor, they don't have listView() anymore, thus they don't
// call deregister( this ), leading to stale entries in the
// itemMap...
while ( TQListViewItem * item = firstChild() )
delete item;
// better do this here, too, since deletion is top-down and thus
// we're deleted when our parent item is no longer a
// KeyListViewItem, but a mere TQListViewItem, so our takeItem()
// overload is gone by that time...
if ( KeyListView * lv = listView() )
@@ -434,7 +434,7 @@ void Kleo::KeyListViewItem::setKey( const GpgME::Key & key ) {
TQString Kleo::KeyListViewItem::toolTip( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->toolTip( key(), col )
- : TQString::null ;
+ : TQString() ;
}
int Kleo::KeyListViewItem::compare( TQListViewItem * item, int col, bool ascending ) const {
@@ -483,45 +483,45 @@ void Kleo::KeyListViewItem::takeItem( TQListViewItem * qlvi ) {
//
//
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * parent, const GpgME::Subkey & subkey )
- : KeyListViewItem( parent, subkey.parent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * tqparent, const GpgME::Subkey & subkey )
+ : KeyListViewItem( tqparent, subkey.tqparent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Subkey & subkey )
- : KeyListViewItem( parent, after, subkey.parent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey )
+ : KeyListViewItem( tqparent, after, subkey.tqparent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * parent, const GpgME::Subkey & subkey )
- : KeyListViewItem( parent, subkey.parent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * tqparent, const GpgME::Subkey & subkey )
+ : KeyListViewItem( tqparent, subkey.tqparent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Subkey & subkey )
- : KeyListViewItem( parent, after, subkey.parent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey )
+ : KeyListViewItem( tqparent, after, subkey.tqparent() ), mSubkey( subkey )
{
}
void Kleo::SubkeyKeyListViewItem::setSubkey( const GpgME::Subkey & subkey ) {
mSubkey = subkey;
- setKey( subkey.parent() );
+ setKey( subkey.tqparent() );
}
TQString Kleo::SubkeyKeyListViewItem::text( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->subkeyText( subkey(), col )
- : TQString::null ;
+ : TQString() ;
}
TQString Kleo::SubkeyKeyListViewItem::toolTip( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->subkeyToolTip( subkey(), col )
- : TQString::null ;
+ : TQString() ;
}
const TQPixmap * Kleo::SubkeyKeyListViewItem::pixmap( int col ) const {
@@ -561,45 +561,45 @@ void Kleo::SubkeyKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
//
//
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * parent, const GpgME::UserID & userID )
- : KeyListViewItem( parent, userID.parent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * tqparent, const GpgME::UserID & userID )
+ : KeyListViewItem( tqparent, userID.tqparent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID & userID )
- : KeyListViewItem( parent, after, userID.parent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID & userID )
+ : KeyListViewItem( tqparent, after, userID.tqparent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID & userID )
- : KeyListViewItem( parent, userID.parent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID & userID )
+ : KeyListViewItem( tqparent, userID.tqparent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID & userID )
- : KeyListViewItem( parent, after, userID.parent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID & userID )
+ : KeyListViewItem( tqparent, after, userID.tqparent() ), mUserID( userID )
{
}
void Kleo::UserIDKeyListViewItem::setUserID( const GpgME::UserID & userID ) {
mUserID = userID;
- setKey( userID.parent() );
+ setKey( userID.tqparent() );
}
TQString Kleo::UserIDKeyListViewItem::text( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->userIDText( userID(), col )
- : TQString::null ;
+ : TQString() ;
}
TQString Kleo::UserIDKeyListViewItem::toolTip( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->userIDToolTip( userID(), col )
- : TQString::null ;
+ : TQString() ;
}
const TQPixmap * Kleo::UserIDKeyListViewItem::pixmap( int col ) const {
@@ -640,45 +640,45 @@ void Kleo::UserIDKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
//
//
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * parent, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( parent, signature.parent().parent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * tqparent, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( tqparent, signature.tqparent().tqparent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( parent, after, signature.parent().parent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( tqparent, after, signature.tqparent().tqparent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( parent, signature.parent().parent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( tqparent, signature.tqparent().tqparent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( parent, after, signature.parent().parent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( tqparent, after, signature.tqparent().tqparent() ), mSignature( signature )
{
}
void Kleo::SignatureKeyListViewItem::setSignature( const GpgME::UserID::Signature & signature ) {
mSignature = signature;
- setKey( signature.parent().parent() );
+ setKey( signature.tqparent().tqparent() );
}
TQString Kleo::SignatureKeyListViewItem::text( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->signatureText( signature(), col )
- : TQString::null ;
+ : TQString() ;
}
TQString Kleo::SignatureKeyListViewItem::toolTip( int col ) const {
return listView() && listView()->columnStrategy()
? listView()->columnStrategy()->signatureToolTip( signature(), col )
- : TQString::null ;
+ : TQString() ;
}
const TQPixmap * Kleo::SignatureKeyListViewItem::pixmap( int col ) const {
@@ -370,39 +370,39 @@ void Kleo::KeyListView::slotEmitContextMenu( KListView*, TQListViewItem * item,
delete item;
// better do this here, too, since deletion is top-down and thus
- // we're deleted when our parent item is no longer a
+ // we're deleted when our tqparent item is no longer a
// KeyListViewItem, but a mere TQListViewItem, so our takeItem()
// overload is gone by that time...